import { LockOutlined } from "@ant-design/icons"
import { App, Button, Form, Input, Modal } from "antd"
import React, { useContext } from "react"
import { savePassWordApi } from "../../api"
import { useAjax } from "../../hooks/useAjax"
import { addAccount } from "../../utils"
import { DispatchContext } from "../../App"
import showMessage from "../../components/showMessage"


interface Props {
    open?: boolean
    onClose?: () => void
    onChange?: () => void
}

/**
 * 修改密码
 * @param param0 
 */
const Modify: React.FC<Props> = ({ open, onClose, onChange }) => {

    /*********************************/
    const { state: { userData: { userName } } } = useContext(DispatchContext)!;
    const [form] = Form.useForm()
    const { message } = App.useApp()
    const savePassWord = useAjax((params) => savePassWordApi(params))
    /*********************************/

    const onFinish = (values: any) => {
        delete values?.newPasswordag
        savePassWord.run(values).then(res => {
            if (+res.code === 200) {
                addAccount(userName, values?.newPassword)
                showMessage.success('修改成功', message)
                onChange?.()
            } else {
                showMessage.error(res.msg || '修改失败', message)
            }
        })
    };

    return <Modal
        open={open}
        width={310}
        centered={true}
        footer={null}
        keyboard={false}
        maskClosable={false}
        onCancel={onClose}
        className="authPop"
    >
        <h4 className="float_pop-tit">修改密码</h4>
        <div style={{ marginTop: 10 }}>
            <Form
                name="modify"
                form={form}
                autoComplete="off"
                onFinish={onFinish}
            >
                <Form.Item name="oldPassword" style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入老密码!' }]}>
                    <Input.Password prefix={<LockOutlined />} placeholder="请输入老密码" size="large" />
                </Form.Item>
                <Form.Item name="newPassword" hasFeedback style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入密码!' }]}>
                    <Input.Password prefix={<LockOutlined />} placeholder="请输入密码" size="large" />
                </Form.Item>
                <Form.Item name="newPasswordag" hasFeedback dependencies={['newPassword']} style={{ marginBottom: 20 }} rules={[
                    { required: true, message: '请再次输入密码!' },
                    ({ getFieldValue }) => ({
                        validator(_, value) {
                            if (!value || getFieldValue('newPassword') === value) {
                                return Promise.resolve();
                            }
                            return Promise.reject(new Error('两次输入密码不一致!'));
                        },
                    })
                ]}>
                    <Input.Password prefix={<LockOutlined />} placeholder="请再次输入密码" size="large" />
                </Form.Item>
                <Form.Item style={{ marginBottom: 10 }}>
                    <Button type="primary" className="form_button" htmlType="submit" loading={savePassWord.loading} size="large">确认</Button>
                </Form.Item>
            </Form>
        </div>
    </Modal>
}

export default React.memo(Modify)